root@proxmox04:/opt/venv/check_zpools/bin# zpool list -j 
{"output_version":{"command":"zpool list","vers_major":0,"vers_minor":1},"pools":{"rpool":{"name":"rpool","type":"POOL","state":"ONLINE","pool_guid":"9142134393397012115","txg":"2632990","spa_version":"5000","zpl_version":"5","properties":{"size":{"value":"464G","source":{"type":"NONE","data":"-"}},"allocated":{"value":"9.35G","source":{"type":"NONE","data":"-"}},"free":{"value":"455G","source":{"type":"NONE","data":"-"}},"checkpoint":{"value":"-","source":{"type":"NONE","data":"-"}},"expandsize":{"value":"-","source":{"type":"NONE","data":"-"}},"fragmentation":{"value":"12%","source":{"type":"NONE","data":"-"}},"capacity":{"value":"2%","source":{"type":"NONE","data":"-"}},"dedupratio":{"value":"1.00x","source":{"type":"NONE","data":"-"}},"health":{"value":"ONLINE","source":{"type":"NONE","data":"-"}},"altroot":{"value":"-","source":{"type":"DEFAULT","data":"-"}}}},"zpool-nvme":{"name":"zpool-nvme","type":"POOL","state":"ONLINE","pool_guid":"15707285985305284701","txg":"2455392","spa_version":"5000","zpl_version":"5","properties":{"size":{"value":"3.62T","source":{"type":"NONE","data":"-"}},"allocated":{"value":"24.2G","source":{"type":"NONE","data":"-"}},"free":{"value":"3.60T","source":{"type":"NONE","data":"-"}},"checkpoint":{"value":"-","source":{"type":"NONE","data":"-"}},"expandsize":{"value":"-","source":{"type":"NONE","data":"-"}},"fragmentation":{"value":"3%","source":{"type":"NONE","data":"-"}},"capacity":{"value":"0%","source":{"type":"NONE","data":"-"}},"dedupratio":{"value":"1.00x","source":{"type":"NONE","data":"-"}},"health":{"value":"ONLINE","source":{"type":"NONE","data":"-"}},"altroot":{"value":"-","source":{"type":"DEFAULT","data":"-"}}}}}}

